@@ -46,7 +46,7 @@ class vis_tools:
         self.colors_seq                 = ['#003366','#A8C5E0','green','lime','sienna','violet']
         self.title_size                 = 20 
         self.axis_size                  = 18 
-        self.label_size                 = 12
+        self.label_size                 = 12 
         self.note_size                  = 18 
         self.dark_blue                  = "#003366"
         self.light_blue                 = "#A8C5E0"
@@ -137,7 +137,7 @@ class vis_tools:
         ax.yaxis.set_tick_params(labelsize=self.label_size)
             
         for i,v in enumerate(y_list):
-            ax.text(v+y_max/20,i-0.2, self.human_format(v),**self.small_label_font)
+            ax.text(v+y_max/20,i-0.2, self.human_format(v))
             ax.set_xticks([])    
         
         ax.spines[['top','right','bottom']].set_visible(False)
@@ -190,7 +190,7 @@ class vis_tools:
 
         x_label_index   = range(len(x_list))
 
-        ax.set_title(title,fontsize=self.title_size,**self.msfont_light)
+        ax.set_title(title,fontsize=self.title_size)
         ax.grid(False) 
         ax.set_facecolor('w') 
         ax.xaxis.set_tick_params(labelsize=self.label_size)
